==> kyamo_0.13.99+0.2a.orig.tar.gz: kyamo-0.2a/src/filter.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Roland Weigert   *
 *   roweigert@t-online.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
using namespace std;

#ifndef _FILTER_H_
#define _FILTER_H_

#include <iostream>

#include <qstring.h>
#include <qstringlist.h>
#include <qfiledialog.h>
#include <qdir.h>
#include <klocale.h>
#include <kapp.h>

#include "id3tag.h"
#include "taglibschnittstelle.h"
#include "rcdatei.h"

//class to handle the sorting-filter

class filter : public QObject
  {
Q_OBJECT
  public:
    filter(QString,QString);
    ~filter()
    {}
    ;
    int makeDirectories(QString,QString);
    int generateName(QString);
    void printFilter();//only for debugging
    bool filterOk;
    QString errorText;
    QString filenamesuggest;
  private:
    QString destdir;
    int checkMnemnomic(QString);
    QString filtertext;
    QStringList *filterparts;
    int mnemnomiccounter;
  };

#endif //_FILTER_H_

==> kyamo_0.40+0.4a.orig.tar.gz: kyamo-0.40a4-2/src/filter.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Roland Weigert   *
 *   roweigert@t-online.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
using namespace std;

#ifndef _FILTER_H_
#define _FILTER_H_

#include <iostream>

#include <qstring.h>
#include <qstringlist.h>
#include <qfiledialog.h>
#include <qdir.h>
#include <klocale.h>
#include <kapp.h>

#include "mnemnomic.h"
#include "mediatag.h"
#include "tagenginewrapper.h"
#include "rcdatei.h"

//class to handle the sorting-filter

class filter : public QObject
  {
Q_OBJECT
  public:
    filter(QString,QString);
    ~filter();
    int makeDirectories(QString,QString);
    int generateName(QString);
    bool filterOk;
    QString errorText;
    QString filenamesuggest;
  private:
    void stripunwantedsigns(mediatag *);
    QString destdir;
    QString filtertext;
    QStringList *filterparts;
    int mnemnomiccounter;
  };

#endif //_FILTER_H_
